@@ -62,8 +62,8 @@ pub fn urlencode<T: AsRef<str>>(s: T) -> String {
 }
 
 pub mod alerts_api;
+pub mod appliances_api;
 pub mod auth_api;
-pub mod devices_api;
 pub mod ml_ops_api;
 pub mod partners_geeks3_api;
 pub mod partners_geeks3d_api;
